<?php

return [
    'cache' => [
        'enabled' => env('KYLIN_SETTINGS_CACHE', true),
        'ttl' => env('KYLIN_SETTINGS_CACHE_TTL', 3600),
        'key' => 'kylin.settings',
    ],
    'table' => 'kylin_settings',
];
