<?php

namespace Kylin\Settings\Facades;

use Illuminate\Support\Facades\Facade;

/**
 * 系统设置门面
 *
 * 提供系统设置服务的静态访问入口。
 */
class KylinSettings extends Facade
{
    protected static function getFacadeAccessor(): string
    {
        return 'kylin-settings';
    }
}
