<?php

declare(strict_types=1);

namespace Kylin\Settings\Policies;

use Kylin\Rbac\Policies\CrudPolicy;

/**
 * 系统设置权限策略
 *
 * 继承 CrudPolicy，自动实现标准 CRUD 权限校验。
 * 权限命名：setting.view、setting.create、setting.update、setting.delete
 */
class SettingPolicy extends CrudPolicy
{
    protected string $resource = 'setting';
}