<?php

use Illuminate\Support\Facades\Route;
use Kylin\Settings\Http\Controllers\SettingController;

Route::prefix('kylin/settings')->middleware(['auth:sanctum'])->group(function () {
    Route::get('/', [SettingController::class, 'index']);
    Route::post('/', [SettingController::class, 'store']);
    Route::get('/{group}/{key}', [SettingController::class, 'show']);
    Route::put('/{group}/{key}', [SettingController::class, 'update']);
    Route::delete('/{group}/{key}', [SettingController::class, 'destroy']);
});
